@@ -92,6 +92,7 @@ class GitPageModel(SlugifyMixin, FilterMixin, models.GitModel):
     modified_at = fields.DateTimeField(required=False)
     published = fields.BooleanField(default=True)
     primary_category = fields.RelatedField(GitCategoryModel, required=False)
+    featured_in_category = fields.BooleanField(default=False)
     language = fields.CharField(required=False)
     source = fields.RelatedField('GitPageModel', required=False)
 
@@ -119,4 +120,5 @@ class GitPageModel(SlugifyMixin, FilterMixin, models.GitModel):
             'modified_at': self.modified_at,
             'published': self.published,
             'primary_category': primary_category,
+            'featured_in_category': self.featured_in_category,
         }
